@@ -6,6 +6,7 @@ import logging
 import re
 
 from django.core.management.commands import startproject
+from django import VERSION as DJANGO_VERSION
 from zc.buildout import UserError
 import zc.recipe.egg
 import setuptools
@@ -89,6 +90,9 @@ class Recipe(object):
         options.setdefault(
             'media_root',
             "os.path.join(os.path.dirname(__file__), 'media')")
+        options.setdefault(
+            'static_root',
+            "os.path.join(os.path.dirname(__file__), 'static')")
         # Set this so the rest of the recipe can expect the values to be
         # there. We need to make sure that both pythonpath and extra-paths are
         # set for BBB.
@@ -138,6 +142,7 @@ class Recipe(object):
         if not self.options.get('projectegg'):
             if not os.path.exists(project_dir):
                 self.create_project(project_dir)
+                self.create_dirs(project_dir)
             else:
                 self.log.info(
                     'Skipping creating of project: %(project)s since '
@@ -152,8 +157,8 @@ class Recipe(object):
             [(self.options.get('control-script', self.name),
               'cykooz.djangorecipe.manage', 'main')],
             ws, self.options['executable'], self.options['bin-directory'],
-            extra_paths = extra_paths,
-            arguments= "'%s.%s'" % (project,
+            extra_paths=extra_paths,
+            arguments="'%s.%s'" % (project,
                                     self.options['settings']))
 
 
@@ -166,8 +171,8 @@ class Recipe(object):
                   'cykooz.djangorecipe.test', 'main')],
                 working_set, self.options['executable'],
                 self.options['bin-directory'],
-                extra_paths = extra_paths,
-                arguments= "'%s.%s', %s" % (
+                extra_paths=extra_paths,
+                arguments="'%s.%s', %s" % (
                     self.options['project'],
                     self.options['settings'],
                     ', '.join(["'%s'" % app for app in apps])))
@@ -182,7 +187,7 @@ class Recipe(object):
             startproject.Command().run_from_argv(['django-admin.py', 'startproject', self.options['project']])
         finally:
             os.chdir(old_cwd)
-        
+
         os.remove(os.path.join(project_dir, 'manage.py'))
 
         template_vars = {}
@@ -198,18 +203,19 @@ class Recipe(object):
 
         settings_path = os.path.join(project_dir, 'settings.py')
         settings = open(settings_path, 'r').read()
-        
+
         # Add the necessary imports
         settings = 'import os\n' + settings
-        
+
         # Set default value for TEMPLATE_DIRS setting
         def_template_dirs = '''os.path.join(os.path.dirname(__file__), 'templates')'''
         settings = re.sub(r'(TEMPLATE_DIRS\s?=\s?\()', '\\1\n    %s,' % def_template_dirs,
                           settings, re.MULTILINE)
 
-        # Change ADMIN_MEDIA_PREFIX setting
-        settings = re.sub(r"(ADMIN_MEDIA_PREFIX\s*?=\s*?')/media/(')", r'\1/admin_media/\2',
-                          settings, re.MULTILINE)
+        if DJANGO_VERSION[0] < 1 or (DJANGO_VERSION[0] == 1 and DJANGO_VERSION[1] < 3):
+            # Change ADMIN_MEDIA_PREFIX setting for Djnago < 1.3
+            settings = re.sub(r"(ADMIN_MEDIA_PREFIX\s*?=\s*?')/media/(')", r'\1/admin_media/\2',
+                              settings, re.MULTILINE)
 
         # Change MEDIA_ROOT setting
         settings = re.sub(r"(MEDIA_ROOT\s*?=\s*?)''", r'\1%s' % self.options['media_root'],
@@ -218,14 +224,36 @@ class Recipe(object):
         # Change MEDIA_URL setting
         settings = re.sub(r"(MEDIA_URL\s*?=\s*?')(')", r'\1/media/\2',
                           settings, re.MULTILINE)
-        
+
+        # Remove TEMPLATE_DEBUG setting
+        settings = re.sub(r"\nTEMPLATE_DEBUG\s*?=.*?\n", '\n', settings, re.MULTILINE)
+
+        # Remove DEBUG setting
+        settings = re.sub(r"\nDEBUG\s*?=.*?\n", '\n', settings, re.MULTILINE)
+
+        if (DJANGO_VERSION[0] == 1 and DJANGO_VERSION[1] >= 3) or DJANGO_VERSION[0] > 1:
+            # Change STATIC_ROOT setting for Django >= 1.3
+            settings = re.sub(r"(STATIC_ROOT\s*?=\s*?)''", r'\1%s' % self.options['static_root'],
+                              settings, re.MULTILINE)
+
         open(settings_path, 'w').write(settings)
-        
+
         # Create the media and templates directories for our project
         os.mkdir(os.path.join(project_dir, 'media'))
         os.mkdir(os.path.join(project_dir, 'templates'))
 
 
+    def create_dirs(self, project_dir):
+        media_path = os.path.join(project_dir, 'media')
+        if not os.path.isdir(media_path):
+            os.mkdir(media_path)
+
+        if (DJANGO_VERSION[0] == 1 and DJANGO_VERSION[1] >= 3) or DJANGO_VERSION[0] > 1:
+            static_path = os.path.join(project_dir, 'static')
+            if not os.path.isdir(static_path):
+                os.mkdir(static_path)
+
+
     def make_scripts(self, extra_paths, ws):
         scripts = []
         _script_template = zc.buildout.easy_install.script_template
@@ -240,7 +268,7 @@ class Recipe(object):
                     filename = os.path.basename(self.options['wsgi-script'])
                     dirname = os.path.dirname(self.options['wsgi-script'])
                     dirname = dirname or self.options['bin-directory']
-                else:    
+                else:
                     filename = '%s.%s' % (self.options.get('control-script', self.name), protocol)
                     dirname = self.options['bin-directory']
                 scripts.extend(
@@ -250,7 +278,7 @@ class Recipe(object):
                         self.options['executable'],
                         dirname,
                         extra_paths=extra_paths,
-                        arguments= "'%s.%s', logfile='%s'" % (
+                        arguments="'%s.%s', logfile='%s'" % (
                             project, self.options['settings'],
                             self.options.get('logfile'))))
         zc.buildout.easy_install.script_template = _script_template
