@@ -33,7 +33,7 @@ class TestRecipe(unittest.TestCase):
 
         # We need to create the bin dir since the recipe should be able to expect it exists
         os.mkdir(self.bin_dir)
-        self.default_buildout_options= zc.buildout.buildout._unannotate_section(
+        self.default_buildout_options = zc.buildout.buildout._unannotate_section(
                             zc.buildout.buildout._buildout_default_options.copy())
         self.default_buildout_options.update(
                             {
@@ -83,7 +83,7 @@ class TestRecipe(unittest.TestCase):
                          'eggs': eggs
                         })
         self.assertTrue(recipe.options.get('eggs', '').startswith('Django'))
-        
+
         eggs = 'mock\nDjango == 1.2.5'
         recipe = Recipe({
                          'buildout': self.default_buildout_options,
@@ -161,12 +161,12 @@ class TestRecipe(unittest.TestCase):
         fcgi_script = os.path.join(self.bin_dir, 'django.fcgi')
         contents = open(fcgi_script).read()
         self.assert_("logfile='/foo'" in contents)
-        
+
         # This should have created a wsgi script in the bin dir with given name
         self.recipe.options['wsgi-script'] = 'django_wsgi.py'
         self.recipe.make_scripts([], [])
         wsgi_script = os.path.join(self.bin_dir, 'django_wsgi.py')
-        self.assert_(os.path.exists(wsgi_script))        
+        self.assert_(os.path.exists(wsgi_script))
 
 
     @mock.patch('zc.buildout.easy_install.scripts')
@@ -271,13 +271,13 @@ class TestRecipe(unittest.TestCase):
         manage.return_value = []
         scripts.return_value = []
         testrunner.return_value = []
-        develop.return_value = mock.Mock()  
+        develop.return_value = mock.Mock()
         self.recipe.install()
         self.assertEqual(manage.call_args[0][0][-2:],
                          ['somepackage', 'anotherpackage'])
 
 
-    @mock.patch('zc.recipe.egg.Develop')    
+    @mock.patch('zc.recipe.egg.Develop')
     @mock.patch('site.addsitedir')
     @mock.patch.object(Recipe, 'create_test_runner')
     @mock.patch.object(Recipe, 'create_manage_script')
@@ -300,7 +300,7 @@ class TestRecipe(unittest.TestCase):
         manage.return_value = []
         testrunner.return_value = []
         develop.return_value = mock.Mock()
-        
+
         # The mock values needed to demonstrate the pth-files option.
         addsitedir.return_value = ['extra', 'dirs']
         self.recipe.options['pth-files'] = 'somedir'
@@ -398,11 +398,14 @@ class TestRecipe(unittest.TestCase):
         recipe.make_scripts([], [])
         self.assertEqual(open(wsgi_script).readline(), '#!/python5k\n')
 
-    
+
     def test_settings_import(self):
         project_dir = os.path.join(self.buildout_dir, 'project')
         self.recipe.create_project(project_dir)
-        execfile(os.path.join(project_dir, 'settings.py'), {'__file__': '.'})
+        globals = {'__file__': '.'}
+        execfile(os.path.join(project_dir, 'settings.py'), globals)
+        self.assertTrue('DEBUG' not in globals, "DEBUG option in 'settings.py'")
+        self.assertTrue('TEMPLATE_DEBUG' not in globals, "TEMPLATE_DEBUG option in 'settings.py'")
 
 
 class ScriptTestCase(unittest.TestCase):
@@ -427,7 +430,7 @@ class TestTestScript(ScriptTestCase):
     def test_script(self, execute_manager):
         # The test script should execute the standard Django test
         # command with any apps given as its arguments.
-        test.main('cheeseshop.development',  'spamm', 'eggs')
+        test.main('cheeseshop.development', 'spamm', 'eggs')
         # We only care about the arguments given to execute_manager
         self.assertEqual(execute_manager.call_args[1],
                          {'argv': ['test', 'test', 'spamm', 'eggs']})
